@@ -23,11 +23,7 @@ write(iunit,'(A,I0,A)')"  SUBROUTINE collocate_core_",lp,"(grid,coef_xyz,pol_x,p
 write(iunit,'(A)')""
 write(iunit,'(A)')"    IMPLICIT NONE"
 write(iunit,'(A)')""
-write(iunit,'(A)')"#if defined(__SGL)"
-write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = KIND(0.0)"
-write(iunit,'(A)')"#else"
 write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = SELECTED_REAL_KIND ( 14, 200 )"
-write(iunit,'(A)')"#endif"
 write(iunit,'(A,I0)')" integer, PARAMETER :: lp=",lp
 write(iunit,'(A)')"    integer, INTENT(IN)     :: cmax"
 write(iunit,'(A)')"    integer, INTENT(IN)     :: gridbounds(2,3)"
@@ -55,11 +51,7 @@ write(iunit,'(A,I0,A)')"  SUBROUTINE collocate_core_",lp,"(grid,coef_xyz,pol_x,p
 write(iunit,'(A)')""
 write(iunit,'(A)')"    IMPLICIT NONE"
 write(iunit,'(A)')""
-write(iunit,'(A)')"#if defined(__SGL)"
-write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = KIND(0.0)"
-write(iunit,'(A)')"#else"
 write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = SELECTED_REAL_KIND ( 14, 200 )"
-write(iunit,'(A)')"#endif"
 write(iunit,'(A,I0)')" integer, PARAMETER :: lp=",lp
 write(iunit,'(A)')"    integer, INTENT(IN)     :: cmax"
 write(iunit,'(A)')"    integer, INTENT(IN)     :: gridbounds(2,3)"
@@ -346,11 +338,7 @@ write(iunit,'(A)')"  SUBROUTINE collocate_core_default(grid,coef_xyz,pol_x,pol_y
 write(iunit,'(A)')""
 write(iunit,'(A)')"    IMPLICIT NONE"
 write(iunit,'(A)')""
-write(iunit,'(A)')"#if defined(__SGL)"
-write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = KIND(0.0)"
-write(iunit,'(A)')"#else"
 write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = SELECTED_REAL_KIND ( 14, 200 )"
-write(iunit,'(A)')"#endif"
 write(iunit,'(A)')"    integer, INTENT(IN)     :: lp"
 write(iunit,'(A)')"    integer, INTENT(IN)     :: cmax"
 write(iunit,'(A)')"    integer, INTENT(IN)     :: gridbounds(2,3)"
@@ -486,11 +474,7 @@ write(iunit,'(A,I0,A)')"  SUBROUTINE integrate_core_",lp,"(grid,coef_xyz,pol_x,p
 write(iunit,'(A)')""
 write(iunit,'(A)')"    IMPLICIT NONE"
 write(iunit,'(A)')""
-write(iunit,'(A)')"#if defined(__SGL)"
-write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = KIND(0.0)"
-write(iunit,'(A)')"#else"
 write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = SELECTED_REAL_KIND ( 14, 200 )"
-write(iunit,'(A)')"#endif"
 write(iunit,'(A,I0)')"    integer, PARAMETER      :: lp=",lp
 write(iunit,'(A)')"    integer, INTENT(IN)     :: cmax"
 write(iunit,'(A)')"    integer, INTENT(IN)     :: gridbounds(2,3)"
@@ -519,11 +503,7 @@ write(iunit,'(A,I0,A)')"  SUBROUTINE integrate_core_",lp,"(grid,coef_xyz,pol_x,p
 write(iunit,'(A)')""
 write(iunit,'(A)')"    IMPLICIT NONE"
 write(iunit,'(A)')""
-write(iunit,'(A)')"#if defined(__SGL)"
-write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = KIND(0.0)"
-write(iunit,'(A)')"#else"
 write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = SELECTED_REAL_KIND ( 14, 200 )"
-write(iunit,'(A)')"#endif"
 write(iunit,'(A,I0)')"    integer, PARAMETER      :: lp=",lp
 write(iunit,'(A)')"    integer, INTENT(IN)     :: cmax"
 write(iunit,'(A)')"    integer, INTENT(IN)     :: gridbounds(2,3)"
@@ -781,11 +761,7 @@ write(iunit,'(A)')"  SUBROUTINE integrate_core_default(grid,coef_xyz,pol_x,pol_y
 write(iunit,'(A)')""
 write(iunit,'(A)')"    IMPLICIT NONE"
 write(iunit,'(A)')""
-write(iunit,'(A)')"#if defined(__SGL)"
-write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = KIND(0.0)"
-write(iunit,'(A)')"#else"
 write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = SELECTED_REAL_KIND ( 14, 200 )"
-write(iunit,'(A)')"#endif"
 write(iunit,'(A)')"    integer, INTENT(IN)     :: lp"
 write(iunit,'(A)')"    integer, INTENT(IN)     :: cmax"
 write(iunit,'(A)')"    integer, INTENT(IN)     :: gridbounds(2,3)"
